@@ -49,9 +49,9 @@ pub struct AwsConfig<'a> {
     pub force_display: bool,
 }
 
-impl<'a> Default for AwsConfig<'a> {
+impl Default for AwsConfig<'_> {
     fn default() -> Self {
-        AwsConfig {
+        Self {
             format: "on [$symbol($profile )(\\($region\\) )(\\[$duration\\] )]($style)",
             symbol: "☁️  ",
             style: "bold yellow",
