@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct CharacterConfig<'a> {
     pub format: &'a str,
@@ -15,9 +19,9 @@ pub struct CharacterConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for CharacterConfig<'a> {
+impl Default for CharacterConfig<'_> {
     fn default() -> Self {
-        CharacterConfig {
+        Self {
             format: "$symbol ",
             success_symbol: "[❯](bold green)",
             error_symbol: "[❯](bold red)",
