@@ -22,7 +22,7 @@ pub struct CmdDurationConfig<'a> {
 
 impl Default for CmdDurationConfig<'_> {
     fn default() -> Self {
-        CmdDurationConfig {
+        Self {
             min_time: 2_000,
             format: "took [$duration]($style) ",
             show_milliseconds: false,
