@@ -13,17 +13,19 @@ pub struct CondaConfig<'a> {
     pub symbol: &'a str,
     pub style: &'a str,
     pub ignore_base: bool,
+    pub detect_env_vars: Vec<&'a str>,
     pub disabled: bool,
 }
 
-impl<'a> Default for CondaConfig<'a> {
+impl Default for CondaConfig<'_> {
     fn default() -> Self {
-        CondaConfig {
+        Self {
             truncation_length: 1,
             format: "via [$symbol$environment]($style) ",
             symbol: "🅒 ",
             style: "green bold",
             ignore_base: true,
+            detect_env_vars: vec!["!PIXI_ENVIRONMENT_NAME"],
             disabled: false,
         }
     }
