@@ -18,9 +18,9 @@ pub struct CrystalConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for CrystalConfig<'a> {
+impl Default for CrystalConfig<'_> {
     fn default() -> Self {
-        CrystalConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "🔮 ",
