@@ -18,9 +18,9 @@ pub struct DenoConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for DenoConfig<'a> {
+impl Default for DenoConfig<'_> {
     fn default() -> Self {
-        DenoConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "🦕 ",
