@@ -16,17 +16,19 @@ pub struct EnvVarConfig<'a> {
     pub default: Option<&'a str>,
     pub format: &'a str,
     pub disabled: bool,
+    pub description: &'a str,
 }
 
-impl<'a> Default for EnvVarConfig<'a> {
+impl Default for EnvVarConfig<'_> {
     fn default() -> Self {
-        EnvVarConfig {
+        Self {
             symbol: "",
             style: "black bold dimmed",
             variable: None,
             default: None,
             format: "with [$env_value]($style) ",
             disabled: false,
+            description: "<env_var module>",
         }
     }
 }
