@@ -13,9 +13,9 @@ pub struct FillConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for FillConfig<'a> {
+impl Default for FillConfig<'_> {
     fn default() -> Self {
-        FillConfig {
+        Self {
             style: "bold black",
             symbol: ".",
             disabled: false,
