@@ -15,9 +15,9 @@ pub struct MemoryConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for MemoryConfig<'a> {
+impl Default for MemoryConfig<'_> {
     fn default() -> Self {
-        MemoryConfig {
+        Self {
             threshold: 75,
             format: "via $symbol[$ram( | $swap)]($style) ",
             style: "white bold dimmed",
