@@ -30,6 +30,7 @@ pub mod env_var;
 pub mod erlang;
 pub mod fennel;
 pub mod fill;
+pub mod fortran;
 pub mod fossil_branch;
 pub mod fossil_metrics;
 pub mod gcloud;
@@ -46,6 +47,7 @@ pub mod haskell;
 pub mod haxe;
 pub mod helm;
 pub mod hg_branch;
+pub mod hg_state;
 pub mod hostname;
 pub mod java;
 pub mod jobs;
@@ -100,6 +102,7 @@ pub mod username;
 pub mod v;
 pub mod vagrant;
 pub mod vcsh;
+pub mod xmake;
 pub mod zig;
 
 pub use starship_root::*;
@@ -174,6 +177,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     fill: fill::FillConfig<'a>,
     #[serde(borrow)]
+    fortran: fortran::FortranConfig<'a>,
+    #[serde(borrow)]
     fossil_branch: fossil_branch::FossilBranchConfig<'a>,
     #[serde(borrow)]
     fossil_metrics: fossil_metrics::FossilMetricsConfig<'a>,
@@ -206,6 +211,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     hg_branch: hg_branch::HgBranchConfig<'a>,
     #[serde(borrow)]
+    hg_state: hg_state::HgStateConfig<'a>,
+    #[serde(borrow)]
     hostname: hostname::HostnameConfig<'a>,
     #[serde(borrow)]
     java: java::JavaConfig<'a>,
@@ -311,6 +318,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     vlang: v::VConfig<'a>,
     #[serde(borrow)]
+    xmake: xmake::XMakeConfig<'a>,
+    #[serde(borrow)]
     zig: zig::ZigConfig<'a>,
     #[serde(borrow)]
     custom: IndexMap<String, custom::CustomConfig<'a>>,
