@@ -18,9 +18,9 @@ pub struct NimConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for NimConfig<'a> {
+impl Default for NimConfig<'_> {
     fn default() -> Self {
-        NimConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "👑 ",
