@@ -16,9 +16,9 @@ pub struct PijulConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for PijulConfig<'a> {
+impl Default for PijulConfig<'_> {
     fn default() -> Self {
-        PijulConfig {
+        Self {
             symbol: " ",
             style: "bold purple",
             format: "on [$symbol$channel]($style) ",
