@@ -18,16 +18,16 @@ pub struct PureScriptConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for PureScriptConfig<'a> {
+impl Default for PureScriptConfig<'_> {
     fn default() -> Self {
-        PureScriptConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "<=> ",
             style: "bold white",
             disabled: false,
             detect_extensions: vec!["purs"],
-            detect_files: vec!["spago.dhall"],
+            detect_files: vec!["spago.dhall", "spago.yaml", "spago.lock"],
             detect_folders: vec![],
         }
     }
