@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct RakuConfig<'a> {
     pub format: &'a str,
@@ -14,7 +18,7 @@ pub struct RakuConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for RakuConfig<'a> {
+impl Default for RakuConfig<'_> {
     fn default() -> Self {
         RakuConfig {
             format: "via [$symbol($version-$vm_version )]($style)",
