@@ -14,9 +14,9 @@ pub struct SingularityConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for SingularityConfig<'a> {
+impl Default for SingularityConfig<'_> {
     fn default() -> Self {
-        SingularityConfig {
+        Self {
             format: "[$symbol\\[$env\\]]($style) ",
             symbol: "",
             style: "blue bold dimmed",
