@@ -49,7 +49,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     module.set_segments(match parsed {
         Ok(segments) => segments,
         Err(error) => {
-            log::warn!("Error in module `bun`:\n{}", error);
+            log::warn!("Error in module `bun`:\n{error}");
             return None;
         }
     });
@@ -61,10 +61,10 @@ fn get_bun_version(context: &Context) -> Option<String> {
     context
         .exec_cmd("bun", &["--version"])
         .map(get_command_string_output)
-        .map(parse_bun_version)
+        .map(|s| parse_bun_version(&s))
 }
 
-fn parse_bun_version(bun_version: String) -> String {
+fn parse_bun_version(bun_version: &str) -> String {
     bun_version.trim_end().to_string()
 }
 
@@ -94,6 +94,16 @@ mod tests {
         dir.close()
     }
 
+    #[test]
+    fn folder_with_bun_file_text_lockfile() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+        File::create(dir.path().join("bun.lock"))?.sync_all()?;
+        let actual = ModuleRenderer::new("bun").path(dir.path()).collect();
+        let expected = Some(format!("via {}", Color::Red.bold().paint("🥟 v0.1.4 ")));
+        assert_eq!(expected, actual);
+        dir.close()
+    }
+
     #[test]
     fn no_bun_installed() -> io::Result<()> {
         let dir = tempfile::tempdir()?;
@@ -106,4 +116,17 @@ mod tests {
         assert_eq!(expected, actual);
         dir.close()
     }
+
+    #[test]
+    fn no_bun_installed_text_lockfile() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+        File::create(dir.path().join("bun.lock"))?.sync_all()?;
+        let actual = ModuleRenderer::new("bun")
+            .path(dir.path())
+            .cmd("bun --version", None)
+            .collect();
+        let expected = Some(format!("via {}", Color::Red.bold().paint("🥟 ")));
+        assert_eq!(expected, actual);
+        dir.close()
+    }
 }
