@@ -1,4 +1,4 @@
-use git_repository::state::InProgress;
+use gix::state::InProgress;
 use std::path::PathBuf;
 
 use super::{Context, Module, ModuleConfig};
@@ -39,7 +39,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     module.set_segments(match parsed {
         Ok(segments) => segments,
         Err(error) => {
-            log::warn!("Error in module `git_state`:\n{}", error);
+            log::warn!("Error in module `git_state`:\n{error}");
             return None;
         }
     });
@@ -60,22 +60,12 @@ fn get_state_description<'a>(
             current: None,
             total: None,
         }),
-        InProgress::Revert => Some(StateDescription {
+        InProgress::Revert | InProgress::RevertSequence => Some(StateDescription {
             label: config.revert,
             current: None,
             total: None,
         }),
-        InProgress::RevertSequence => Some(StateDescription {
-            label: config.revert,
-            current: None,
-            total: None,
-        }),
-        InProgress::CherryPick => Some(StateDescription {
-            label: config.cherry_pick,
-            current: None,
-            total: None,
-        }),
-        InProgress::CherryPickSequence => Some(StateDescription {
+        InProgress::CherryPick | InProgress::CherryPickSequence => Some(StateDescription {
             label: config.cherry_pick,
             current: None,
             total: None,
@@ -95,8 +85,9 @@ fn get_state_description<'a>(
             current: None,
             total: None,
         }),
-        InProgress::Rebase => Some(describe_rebase(repo, config.rebase)),
-        InProgress::RebaseInteractive => Some(describe_rebase(repo, config.rebase)),
+        InProgress::Rebase | InProgress::RebaseInteractive => {
+            Some(describe_rebase(repo, config.rebase))
+        }
     }
 }
 
