@@ -1,6 +1,6 @@
 use systemstat::{
-    data::{saturating_sub_bytes, ByteSize},
     Platform, System,
+    data::{ByteSize, saturating_sub_bytes},
 };
 
 use super::{Context, Module, ModuleConfig};
@@ -62,13 +62,12 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
         Ok((mem, _)) => (mem, None),
         Err(e) => {
             log::debug!(
-                "Failed to retrieve both memory and swap, falling back to memory only: {}",
-                e
+                "Failed to retrieve both memory and swap, falling back to memory only: {e}"
             );
             let mem = match system.memory() {
                 Ok(mem) => mem,
                 Err(e) => {
-                    log::warn!("Failed to retrieve memory: {}", e);
+                    log::warn!("Failed to retrieve memory: {e}");
                     return None;
                 }
             };
@@ -95,7 +94,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
             })
             .map(|variable| match variable {
                 "ram" => Some(Ok(format_usage_total(memory.total, memory.free))),
-                "ram_pct" => Some(Ok(format!("{:.0}%", used_pct))),
+                "ram_pct" => Some(Ok(format!("{used_pct:.0}%"))),
                 "swap" => Some(Ok(format_usage_total(
                     swap.as_ref()?.total,
                     swap.as_ref()?.free,
@@ -112,7 +111,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     module.set_segments(match parsed {
         Ok(segments) => segments,
         Err(error) => {
-            log::warn!("Error in module `memory_usage`:\n{}", error);
+            log::warn!("Error in module `memory_usage`:\n{error}");
             return None;
         }
     });
@@ -171,7 +170,7 @@ mod test {
             })
             .collect();
 
-        assert!(output.is_some())
+        assert!(output.is_some());
     }
 
     #[test]
@@ -184,6 +183,6 @@ mod test {
             })
             .collect();
 
-        assert!(output.is_none())
+        assert!(output.is_none());
     }
 }
