@@ -37,7 +37,10 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
             .map(|variable| match variable {
                 "version" => {
                     let terraform_version = parse_terraform_version(
-                        context.exec_cmd("terraform", &["version"])?.stdout.as_str(),
+                        context
+                            .exec_cmds_return_first(&config.commands)?
+                            .stdout
+                            .as_str(),
                     )?;
                     VersionFormatter::format_module_version(
                         module.get_name(),
@@ -55,7 +58,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     module.set_segments(match parsed {
         Ok(segments) => segments,
         Err(error) => {
-            log::warn!("Error in module `terraform`:\n{}", error);
+            log::warn!("Error in module `terraform`:\n{error}");
             return None;
         }
     });
@@ -84,13 +87,15 @@ fn get_terraform_workspace(context: &Context) -> Option<String> {
 }
 
 fn parse_terraform_version(version: &str) -> Option<String> {
-    // `terraform version` output looks like this
-    // Terraform v0.12.14
-    // With potential extra output if it detects you are not running the latest version
+    // `terraform version` or `tofu version` output looks like this
+    //   Terraform v0.12.14/OpenTofu v1.7.2
+    // with potential extra output if it detects you are not running the latest version
+
     let version = version
         .lines()
         .next()?
         .trim_start_matches("Terraform ")
+        .trim_start_matches("OpenTofu ")
         .trim()
         .trim_start_matches('v');
 
@@ -111,6 +116,22 @@ mod tests {
         assert_eq!(parse_terraform_version(input), Some("0.12.14".to_string()));
     }
 
+    #[test]
+    fn test_parse_opentofu_version_release() {
+        let input = "OpenTofu v1.7.2";
+        assert_eq!(parse_terraform_version(input), Some("1.7.2".to_string()));
+    }
+
+    #[test]
+    fn test_parse_opentofu_version_multiline() {
+        let input = "OpenTofu v1.7.2
+on darwin_arm64
++ provider registry.opentofu.org/hashicorp/helm v2.14.0
++ provider registry.opentofu.org/hashicorp/kubernetes v2.31.0
+";
+        assert_eq!(parse_terraform_version(input), Some("1.7.2".to_string()));
+    }
+
     #[test]
     fn test_parse_terraform_version_prerelease() {
         let input = "Terraform v0.12.14-rc1";
@@ -120,6 +141,15 @@ mod tests {
         );
     }
 
+    #[test]
+    fn test_parse_opentofu_version_prerelease() {
+        let input = "OpenTofu v1.8.0-alpha1";
+        assert_eq!(
+            parse_terraform_version(input),
+            Some("1.8.0-alpha1".to_string())
+        )
+    }
+
     #[test]
     fn test_parse_terraform_version_development() {
         let input = "Terraform v0.12.14-dev (cca89f74)";
@@ -144,7 +174,7 @@ is 0.12.14. You can update by downloading from www.terraform.io/downloads.html
     fn folder_with_dotterraform_with_version_no_environment() -> io::Result<()> {
         let dir = tempfile::tempdir()?;
         let tf_dir = dir.path().join(".terraform");
-        fs::create_dir(&tf_dir)?;
+        fs::create_dir(tf_dir)?;
 
         let actual = ModuleRenderer::new("terraform")
             .path(dir.path())
@@ -259,7 +289,7 @@ is 0.12.14. You can update by downloading from www.terraform.io/downloads.html
     fn folder_with_dotterraform_no_environment() -> io::Result<()> {
         let dir = tempfile::tempdir()?;
         let tf_dir = dir.path().join(".terraform");
-        fs::create_dir(&tf_dir)?;
+        fs::create_dir(tf_dir)?;
 
         let actual = ModuleRenderer::new("terraform").path(dir.path()).collect();
         let expected = Some(format!(
